@@ -90,9 +90,6 @@ private Q_SLOTS:
 
 void KFileWidgetTest::initTestCase()
 {
-    // To avoid a runtime dependency on klauncher
-    qputenv("KDE_FORK_SLAVES", "yes");
-
     QStandardPaths::setTestModeEnabled(true);
 
     QVERIFY(QDir::homePath() != QDir::tempPath());
@@ -675,6 +672,33 @@ void KFileWidgetTest::testTokenize_data()
     QTest::newRow("file-beginning-with-colon") << QStringList{":test2"} << QString{":test2"};
 
     QTest::newRow("multiple-files-beginning-with-colon") << QStringList{":test space", ":test2"} << QString{"\":test space\" \":test2\""};
+
+    // # 473228
+    QTest::newRow("file-beginning-with-something-that-looks-like-a-url-scheme") << QStringList{"Hello: foo.txt"} << QString{"Hello: foo.txt"};
+    QTest::newRow("file-beginning-with-something-that-looks-like-a-file-url-scheme") << QStringList{"file: /foo.txt"} << QString{"file: /foo.txt"};
+
+    QTemporaryDir otherTempDir;
+    otherTempDir.setAutoRemove(false);
+    const auto testFile1Path = otherTempDir.filePath("test-1");
+    createTestFile(testFile1Path);
+    const auto testFile2Path = otherTempDir.filePath("test-2");
+    createTestFile(testFile2Path);
+
+    QTest::newRow("absolute-url-not-in-dir") << QStringList{"file://" + testFile1Path} << QString{"file://" + testFile1Path};
+    QTest::newRow("absolute-urls-not-in-dir") << QStringList{"file://" + testFile1Path, "file://" + testFile2Path}
+                                              << QString{"\"file://" + testFile1Path + "\" \"file://" + testFile2Path + "\""};
+
+    auto expectedtestFile1Path = testFile1Path;
+    expectedtestFile1Path = expectedtestFile1Path.remove(0, 1);
+    auto expectedtestFile2Path = testFile2Path;
+    expectedtestFile2Path = expectedtestFile2Path.remove(0, 1);
+
+    QTest::newRow("absolute-url-not-in-dir-no-scheme") << QStringList{testFile1Path} << QString{testFile1Path};
+    QTest::newRow("absolute-urls-not-in-dir-no-scheme")
+        << QStringList{testFile1Path, testFile2Path} << QString{"\"" + testFile1Path + "\" \"" + testFile2Path + "\""};
+
+    QTest::newRow("absolute-urls-not-in-dir-scheme-mixed")
+        << QStringList{testFile1Path, "file://" + testFile2Path} << QString{"\"" + testFile1Path + "\" \"file://" + testFile2Path + "\""};
 }
 
 void KFileWidgetTest::testTokenize()
@@ -690,8 +714,11 @@ void KFileWidgetTest::testTokenize()
     const QUrl tempDirUrl = QUrl::fromLocalFile(tempDirPath);
     QList<QUrl> fileUrls;
     for (const auto &fileName : fileNames) {
-        const QString filePath = tempDirPath + QLatin1Char('/') + fileName;
-        const QUrl localUrl = QUrl::fromLocalFile(filePath);
+        auto localUrl = QUrl(fileName);
+        if (!localUrl.path().startsWith(QLatin1Char('/'))) {
+            const QString filePath = tempDirPath + QLatin1Char('/') + fileName;
+            localUrl = QUrl::fromLocalFile(filePath);
+        }
         fileUrls.append(localUrl);
         qCDebug(KIO_KFILEWIDGETS_FW) << fileName << " => " << localUrl;
     }
@@ -714,6 +741,12 @@ void KFileWidgetTest::testTokenize()
 
     // We must have the same size as requested files
     QCOMPARE(urls.size(), fileNames.size());
+
+    for (auto &localUrl : fileUrls) {
+        if (localUrl.scheme().isEmpty()) {
+            localUrl.setScheme("file");
+        }
+    }
     QCOMPARE(urls, fileUrls);
 }
 
