@@ -83,9 +83,11 @@ public:
     void jobFinished(KIO::SimpleJob *job, KIO::Slave *slave);
     void putSlaveOnHold(KIO::SimpleJob *job, const QUrl &url);
     void removeSlaveOnHold();
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 91)
     Slave *getConnectedSlave(const QUrl &url, const KIO::MetaData &metaData);
     bool assignJobToSlave(KIO::Slave *slave, KIO::SimpleJob *job);
     bool disconnectSlave(KIO::Slave *slave);
+#endif
     Slave *heldSlaveForJob(KIO::SimpleJob *job);
     bool isSlaveOnHoldFor(const QUrl &url);
     void updateInternalMetaData(SimpleJob *job);
@@ -99,7 +101,6 @@ public:
 #ifndef KIO_ANDROID_STUB
     void slotReparseSlaveConfiguration(const QString &, const QDBusMessage &);
 #endif
-    void slotSlaveOnHoldListChanged();
 
 #if KIOCORE_BUILD_DEPRECATED_SINCE(5, 91)
     void slotSlaveConnected();
@@ -292,6 +293,7 @@ QList<Slave *> HostQueue::allSlaves() const
     return ret;
 }
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 91)
 ConnectedSlaveQueue::ConnectedSlaveQueue()
 {
     m_startJobsTimer.setSingleShot(true);
@@ -430,6 +432,7 @@ void ConnectedSlaveQueue::startRunnableJobs()
         startJob(job, slave);
     }
 }
+#endif
 
 static void ensureNoDuplicates(QMap<int, HostQueue *> *queuesBySerial)
 {
@@ -598,6 +601,7 @@ void ProtoQueue::removeJob(SimpleJob *job)
         }
         // just in case; startAJob() will refuse to start a job if it shouldn't.
         m_startJobTimer.start();
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 91)
     } else {
         // should be a connected slave
         // if the assertion fails the job has probably changed the host part of its URL while
@@ -605,6 +609,7 @@ void ProtoQueue::removeJob(SimpleJob *job)
         const bool removed = m_connectedSlaveQueue.removeJob(job);
         Q_UNUSED(removed);
         Q_ASSERT(removed);
+#endif
     }
 
     ensureNoDuplicates(&m_queuesBySerial);
@@ -620,7 +625,7 @@ Slave *ProtoQueue::createSlave(const QString &protocol, SimpleJob *job, const QU
             schedulerPrivate()->slotSlaveDied(slave);
         });
     } else {
-        qCWarning(KIO_CORE) << "couldn't create slave:" << errortext;
+        qCWarning(KIO_CORE) << "couldn't create worker:" << errortext;
         if (job) {
             job->slotError(error, errortext);
         }
@@ -630,10 +635,15 @@ Slave *ProtoQueue::createSlave(const QString &protocol, SimpleJob *job, const QU
 
 bool ProtoQueue::removeSlave(KIO::Slave *slave)
 {
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 91)
     const bool removedConnected = m_connectedSlaveQueue.removeSlave(slave);
     const bool removedUnconnected = m_slaveKeeper.removeSlave(slave);
     Q_ASSERT(!(removedConnected && removedUnconnected));
     return removedConnected || removedUnconnected;
+#else
+    const bool removed = m_slaveKeeper.removeSlave(slave);
+    return removed;
+#endif
 }
 
 QList<Slave *> ProtoQueue::allSlaves() const
@@ -643,7 +653,9 @@ QList<Slave *> ProtoQueue::allSlaves() const
     for (; it != m_queuesByHostname.cend(); ++it) {
         ret.append(it.value().allSlaves());
     }
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 91)
     ret.append(m_connectedSlaveQueue.allSlaves());
+#endif
     return ret;
 }
 
@@ -748,7 +760,6 @@ Scheduler::Scheduler()
                  QStringLiteral("reparseSlaveConfiguration"),
                  this,
                  SLOT(slotReparseSlaveConfiguration(QString, QDBusMessage)));
-    dbus.connect(QString(), dbusPath, dbusInterface, QStringLiteral("slaveOnHoldListChanged"), this, SLOT(slotSlaveOnHoldListChanged()));
 #endif
 }
 
@@ -855,25 +866,33 @@ bool Scheduler::disconnectSlave(KIO::Slave *slave)
 }
 #endif
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 103)
 bool Scheduler::connect(const char *signal, const QObject *receiver, const char *member)
 {
     return QObject::connect(self(), signal, receiver, member);
 }
+#endif
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 103)
 bool Scheduler::connect(const QObject *sender, const char *signal, const QObject *receiver, const char *member)
 {
     return QObject::connect(sender, signal, receiver, member);
 }
+#endif
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 103)
 bool Scheduler::disconnect(const QObject *sender, const char *signal, const QObject *receiver, const char *member)
 {
     return QObject::disconnect(sender, signal, receiver, member);
 }
+#endif
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 103)
 bool Scheduler::connect(const QObject *sender, const char *signal, const char *member)
 {
     return QObject::connect(sender, signal, member);
 }
+#endif
 
 #if KIOCORE_BUILD_DEPRECATED_SINCE(5, 88)
 void Scheduler::checkSlaveOnHold(bool)
@@ -931,10 +950,6 @@ void SchedulerPrivate::slotReparseSlaveConfiguration(const QString &proto, const
 }
 #endif
 
-void SchedulerPrivate::slotSlaveOnHoldListChanged()
-{
-}
-
 void SchedulerPrivate::doJob(SimpleJob *job)
 {
     // qDebug() << job;
